Welcome to pythonthesorimed documentation!
===========================================

.. toctree::
	:maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`